package ittp.protocol.request.headers;

import ittp.protocol.request.Request;
import ittp.ittpException;
import ittp.protocol.response.Response;

/**
 * This class analyse the header Range send by the client.
 * @author Frederic Bidon and Mathieu Texier
 */
public class Range extends Request.Headers{
    private int first;
    private int last;
    private boolean used = false;
    private Request parent;
    /**Constructor of the class*/
    public Range (Request parent) {
        parent.super ();
        this.parent = parent;
    }
    
    /**
     * Mutators for the range (the first and the last octet of the portion).
     * @param first int that contain the first octet of the portion requested by the client.
     * @param last int that contain the last octet of the portion requested by the client.
     * @throws ittpException if the headers Range already received.
     */
    public void setRange (int first, int last) throws ittpException {
        if (used)
            throw new ittpException ("headers Range already received", Response.Code.ITTP_BAD_REQUEST);
        this.first = first;
        this.last = last;
        if ((last > parent.getFile ().length ()) || (last < first))
            throw new ittpException ("headers Range already received", Response.Code.ITTP_OUT_OF_RANGE);
        used = true;
    }
    
    /**
     * Accessors for the number of the first octet of the body.
     * @return the int first.
     */
    public int getFirst () {
        return first;
    }
    
    /**
     * Accessors for the number of the last octet of the body.
     * @return the int last.
     */
    public int getLast () {
        return last;
    }
    
    /**
     * Convert to a string the headers range send by the client.
     * @return a string containing the response to this headers if it is used.
     */
    public String toString () {
        if (used)
            return "Range:" + first +"-"+ last + "\n";
        else return "";
    }
    
    /**
     * Accessors for the boolean used.
     * @return used: boolean that determine if this headers is used.
     */
    public boolean isUsed () {
        return used;
    }
}
