/*
 * ITTPParserTest.java
 * JUnit based test
 *
 * Created on 18 novembre 2004, 18:40
 */

package test;

import ittp.protocol.parser.*;
import ittp.protocol.request.*;
import ittp.protocol.*;
import java.text.SimpleDateFormat;
import java.text.ParsePosition;
import java.text.FieldPosition;
import java.text.DateFormat;
import java.util.Date;
import java.util.Locale;
import junit.framework.*;
import java.net.*;
import java.io.*;

/**
 *
 * @author mathieu
 */
public class ITTPParserTest extends TestCase {
    
    public ITTPParserTest (java.lang.String testName) {
        super (testName);
    }
    
    public static Test suite () {
        TestSuite suite = new TestSuite (ITTPParserTest.class);
        return suite;
    }
    
    /**
     * Test of parse method, of class Parser.ITTPParser.
     */
    static public void testParse () {
        String CorrectRequestTab[] = new String [] {
            "HEAD /test.txt ITTP/1.3\n\n",
            "GET /test.txt ITTP/1.3\n\n",
            "TRACE /test.txt ITTP/1.3\n\n",
            "OPTIONS /test.txt ITTP/1.3\n\n",
            "HEAD ittp:/test.txt ITTP/1.3 \n\n",
            "HEAD ittp:/test/test.txt ITTP/1.3 \n\n",
            "HEAD //localhost/test.txt ITTP/1.3\n\n",
            "HEAD //127.0.0.1/test.txt ITTP/1.3\n\n",
            "HEAD //127.0.0.1:36000/test.txt ITTP/1.3\n\n",
            "HEAD //localhost:36000/test/test.txt ITTP/1.3\n\n",
            "HEAD ittp://localhost:36000/test/test.txt ITTP/1.3\n\n",
            "HEAD ittp:\\\\localhost:36000\\test\\test.txt ITTP\\1.3\n\n",
            "HEAD ittp://      localhost:36000/  test/test.txt ITTP/1.3\n\n",
            /* headers */
            "GET /test.txt ITTP/1.3 \n" +
            "If-Modified-Since: Wed, 4 Jul 2001 10:08:56 CET\n\n",
            "GET /test.txt ITTP/1.3\n" +
            "Range: 1 - 10\n\n",
            "GET /test.txt ITTP/1.3\n" +
            "Range: 1-10\n\n",
            "GET /test.txt ITTP/1.3\n" +
            "Host: localhost\n\n",
            "GET /test.txt ITTP/1.3\n" +
            "Connection: close\n\n",
            "GET /test.txt ITTP/1.3\n\n"
        };

        String EroneusRequestTab[][] = new String [][] {
            {"check of the gramar", null},
            {"bad method", "GETs /test.txt ITTP/1.3 \n\n"},
            {"no slash", "GET test.txt ITTP/1.3 \n\n"},
            {"wrong protocol", "GET /test.txt TTP/1.3 \n\n"},
            {"wrong protocol", "GET /test.txt TTP/1.3 \n\n"},
            {"check of the correctness of the value", null},
            {"file does not exist", "GET test.txt ITTP/1.3 \n\n"},
            {"wrong protocol version", "GET /test.txt ITTP/1.2 \n\n"},
            {"wrong value connection", "GET /test.txt ITTP/1.3\n Connection: open\n\n"},
            {"wrong value for headers Range", "GET /test.txt ITTP/1.3\n Range: 10-10000\n\n"},
            {"wrong value for headers Range (1 value)", "GET /test.txt ITTP/1.3\n Range: 1-\n\n"},
            {"wrong value for headers Range (null)", "GET /test.txt ITTP/1.3\n Range: \n\n"},
            {"wrong value for headers Range (last < first)", "GET /test.txt ITTP/1.3\n Range: 5-1\n\n"},
            {"wrong headers ", "GET /test.txt ITTP/1.3\n size: test.txt\n\n"},
            {"wrong date ", "GET /test.txt ITTP/1.3\n Date: Wed, 4 Jul 2001 10:08:56 CET\n\n"},
            {"wrong date (null)", "GET /test.txt ITTP/1.3\n Date: \n\n"},
            {"wrong date If-Modified-Since (null)", "GET /test.txt ITTP/1.3\n If-Modified-Since: \n\n"},
            {"wrong host (null)", "GET /test.txt ITTP/1.3\n Host: \n\n"}
        };
        for (int i=0;i<CorrectRequestTab.length;i++) {
            try {
                BufferedReader in = new BufferedReader (new StringReader (CorrectRequestTab[i]));
                RequestParser p = new RequestParser (in, null);
                Request request = p.parse ();
                System.out.print ("send " + CorrectRequestTab[i]);
                System.out.println ("   parser : " + request);
            } catch (Exception e) {
                e.printStackTrace ();
                fail ("request "+ i + " : " +e.getMessage ());
            }
        }
        
        for (int i=0;i<EroneusRequestTab.length;i++) {
            if (EroneusRequestTab[i][1] != null) {
                try {
                    BufferedReader in = new BufferedReader (new StringReader (EroneusRequestTab[i][1]));
                    RequestParser p = new RequestParser (in, null);
                    Request request = p.parse ();
                    System.out.println (request);
                    fail ("request "+ i + " : error not catch");
                } catch (Exception e) {
                    System.out.println (EroneusRequestTab[i][0] + " OK :\n\t" + e.getMessage ());
                }
            } else {
                System.out.println ("**************" + EroneusRequestTab[i][0] + "**************");
            }
        }
    }
}

